<?php 
use Automattic\WooCommerce\Utilities\OrderUtil;
use Automattic\WooCommerce\Internal\DataStores\Orders\CustomOrdersTableController;

class WCAM_OrderAddon
{
	var $current_order = 0;
	var $errors;
	var $messages;
	var $results;
	public function __construct()
	{
		add_action( 'add_meta_boxes', array( &$this, 'woocommerce_attachment_metaboxes' ) );
		add_action( 'wp_ajax_upload_attachments', array( &$this, 'woocommerce_process_shop_ordermeta' ) );
		add_action( 'wp_ajax_wcam_load_order_attachments_metabox', array( &$this, 'ajax_load_order_attachments_metabox' ) );
		add_action( 'wp_ajax_wcam_upload_attachments_csv', array( &$this, 'import_attachments_csv_chunk' ) );
	}
	
	function import_attachments_csv_chunk()
	{
		global $wcam_order_model;
		$csv_array = explode("<#>", $_POST['csv']);
		$results = $wcam_order_model->process_upload_csv_chunk($csv_array);
		$this->messages = $results['messages'];
		$this->errors = $results['errors'];
		
		 if ( isset($this->errors) && count($this->errors) > 0):  ?>
			<div class="error">
					<ul>
				<?php foreach($this->errors as $error)
				
			 if ( is_wp_error($error) ) : ?>
				
					<?php
						foreach ( $error->get_error_messages() as $err )
							echo "<li>$err</li>\n";
					endif; ?>
					</ul>
				</div>
			<?php endif;

			if ( ! empty( $this->messages ) ) {
				foreach ( $this->messages as $msg )
					echo '<div id="message" class="updated"><p>' . $msg . '</p></div>';
			} 
		wp_die();
	}
	//Save uploads and options
	public function woocommerce_process_shop_ordermeta( ) 
	{
		if(!isset($_POST["wcam-orderid"]))
			return;
		
		global $wcam_order_model;
		$results = $wcam_order_model->save_attachments($_POST, $_FILES);
		$this->errors = $results['errors'];
		$this->results = $results['results'];
		
		$this->woocommerce_order_attachments_box(wc_get_order( $_POST["wcam-orderid"] )); 
		wp_die();
	}
	public function woocommerce_attachment_metaboxes()
	{
		$screen = wc_get_container()->get( CustomOrdersTableController::class )->custom_orders_table_usage_is_enabled()
		? wc_get_page_screen_id( 'shop-order' )
		: 'shop_order';

		add_meta_box( 'woocommerce-attach-me', esc_html__('Attachments box', 'woocommerce-attach-me'), array( &$this, 'woocommerce_order_attachments_box' ), $screen, 'normal', 'default');
	}
	function ajax_load_order_attachments_metabox($order)
	{
		$order_id = isset($_POST['order_id']) ? $_POST['order_id'] : false;
		if(!$order_id)
			wp_die();
		
		
		$this->woocommerce_order_attachments_box(wc_get_order($order_id), false);
		
		wp_die();
		
	}
	public function woocommerce_order_attachments_box($post_or_order_object, $init_js_data = true)
	{
		global $wcam_order_model, $wcam_file_model, $wcam_time_model, $wcam_html_model;
		
		if(!$post_or_order_object || !is_object($post_or_order_object)) 
			return;
		
		$order = ( $post_or_order_object instanceof WP_Post ) ? wc_get_order( $post_or_order_object->ID ) : $post_or_order_object;
		$order_id = ( $post_or_order_object instanceof WP_Post ) ? $post_or_order_object->ID : $order->get_id();
		
		if($init_js_data)
			$wcam_html_model->init_attachments_metabox_js($order_id);
		
		$attachments_meta = $wcam_order_model->get_attachmets_meta($order_id);
		$wcam_options = $wcam_order_model->get_post_options($order_id);
		$custom_order_status_emails = WCAM_Email::get_wc_order_status_emails();
		
		$wc_order = wc_get_order($order_id);
		$general_options_model = new WCAM_Option();
		$general_options = $general_options_model->get_option();
		$wpml = new WCAM_Wpml();
		$order_lang = $wcam_order_model->get_lang($order_id);
		$curr_lang = $wpml->get_current_language();
		$order_statuses = wc_get_order_statuses();
		
		//The method checks if according option the expired attachments can be deleted
		$wcam_file_model->delete_expired_attachments($order_id);
		
		//init 		
		$general_options['default_attachment_title'][$curr_lang] = !isset($general_options['default_attachment_title'][$curr_lang]) ? esc_html__('Attachment', 'woocommerce-attach-me'): $general_options['default_attachment_title'][$curr_lang];
		?>
		<div id="wcam-attachments-box">	
		<?php if(isset($this->errors))
			echo '<h4 style="color:red">'.$this->errors.'</h4>'; ?>
		<?php if(isset($this->results))
			echo '<h4 style="color:green">'.$this->results.'</h4>'; ?>
		 <div id="wcam-uploads-data">
		 
			
			<ul id="wcam-attachments-list">
			<input type="hidden" name="wcam-orderid" id="wcam-orderid" value="<?php echo $order_id; ?>"></input>
			<?php $counter =  $max_id = 0;
			if(!$attachments_meta || empty($attachments_meta)): 
						?>
						<li class="wcam-attachment-box" data-id="0" data-already-uploaded="no">
							<input type="hidden" name="wcam_id[0]" value="0" ></input>
							<h2 ><div class="button wcam_collapse_expand_button" data-id="0">-</div><?php esc_html_e('New attachment', 'woocommerce-attach-me'); ?></h2>
							
							<div class="wcam-attachment-box-content" id="wcam-attachment-box-content-0" data-already-collapsed="no">
								<h4 ><?php esc_html_e('Shortcode', 'woocommerce-attach-me'); ?></h4>
								<a href="#" class="wcam_tooltip">
									[wcam_download_link id="0"]
									<span>
										<?php esc_html_e('Paste the following shortcode ', 'woocommerce-attach-me'); ?> <b>[wcam_download_link id="0"]</b>  <?php esc_html_e('in the notification email body (see down below) to embed a direct link to download/view the file.', 'woocommerce-attach-me'); ?>
									</span>
								</a>
								
								
								<h4 ><?php esc_html_e('Attachment title', 'woocommerce-attach-me'); ?></h4>
								<input style="display:block;" type="text"  class="wcam-attachments-titles" id="wcam_attachment_title_0" name="wcam_attachment_title[0]" placeholder="<?php esc_html_e('Title/description', 'woocommerce-attach-me'); ?>" value="<?php if(isset($general_options['default_attachment_title'][$curr_lang])) echo $general_options['default_attachment_title'][$curr_lang];?>"></input>
								<div id="wcam-file-data-box">
									<fieldset>
										<input type="radio" id="wcam-radio-file-0" name="wcam-attachment-type0" value="file" checked="checked">	</input>
										<label class="wcam-label" ><?php esc_html_e('Upload a file', 'woocommerce-attach-me'); ?></label>
										<input style="display:block; margin-bottom:15px;" type="file" class="file_input" name="wcam_attachment_file-0" ></input>
									
										<input type="radio" id="wcam-radio-ext-0" name="wcam-attachment-type0" value="ext"></input>
										<label class="wcam-label" ><?php esc_html_e('Or attach an external URL:', 'woocommerce-attach-me'); ?></label>
										<input style="display:block; margin-bottom:15px;" class="wcam-external-url" id="wcam-external-link-0" type="text" name="wcam_attachment_external_url[0]" placeholder="<?php esc_html_e('Ex: http://www.gdocs.com/file.jpg', 'woocommerce-attach-me'); ?>"></input>
										
										<input type="radio" id="wcam-radio-gallery-0" name="wcam-attachment-type0"  value="file"></input>
										<label class="wcam-label" ><?php esc_html_e('Or attach from gallery:', 'woocommerce-attach-me'); ?></label>
										<input id="wcam-gallery-link-0"  class="wcam-gallery-input"  type="text" class="wcam-gallery-attachment" name="wcam_attachment_gallery_url[0]" placeholder="<?php esc_attr_e('Click on the "Browse from Media gallery" button', 'woocommerce-attach-me'); ?>" readonly></input>
										<input type="hidden" id="gallery_media_id_0" name="wcam_attachment_gallery_media_id[0]"></input>
										<input type="button" data-id="0" class="wcam-browse-link button" value="<?php esc_html_e('Browse from Media gallery', 'woocommerce-attach-me') ?>" ></input>								
									</fieldset>
									
									<h4><?php esc_html_e('Attachment description (optional)', 'woocommerce-attach-me'); ?></h4>
									<textarea rows="4" cols="30" id="wcam-attachment-description-0" data-id="0" class="wcam-attachment-description" placeholder="<?php esc_html_e('Ex.: To view, click on the follow link [wcam_download_link]', 'woocommerce-attach-me'); ?>" name="wcam-attachment-description[0]"></textarea>
									<?php /* If needed, the textarea can be created via wp_editor, it however doesn't work when dinamically addede via js:
											wp_editor( "", 'reply_message', array(
											'wpautop'       => true,
											'media_buttons' => true,
											'textarea_name' => 'wcam_attachment_description[0]',
											'textarea_rows' => 10,
											'teeny'         => true
										) ); */ ?>
								</div>
								
								<button class="button wccm_advanced_option_button" data-id="0" ><?php esc_html_e('Show/Hide advanced options', 'woocommerce-attach-me'); ?></button>
								<div class="wccm_advanced_option_box" id="wcam-advanced-options-box-0">
								
									<input type="checkbox" name="wcam-secure-download[0]" id="wcam-secure-download-0" class="wcam-customer-approve-checkbox" value="yes" <?php if(isset($general_options['secure_download']) && $general_options['secure_download'] == 'yes') echo 'checked="checked"';?>></input>
									<label class="wcam-label"  ><?php esc_html_e('Secure download (Only the owner of the order can view/download the file). This option will not work with external  links.', 'woocommerce-attach-me'); ?></label>
									<br/>									
									<input type="checkbox" name="wcam-customer-approve-checkbox[0]" class="wcam-customer-approve-checkbox" value="yes" <?php if(isset($general_options['approve_checkbox_default_value']) && $general_options['approve_checkbox_default_value'] == 'yes') echo 'checked="checked"';?>></input>
									<label class="wcam-label"  ><?php esc_html_e('Enable customer approval? ', 'woocommerce-attach-me'); ?></label>
									<br/>
									<input type="checkbox"  name="wcam-customer-reapprove-checkbox[0]" class="wcam-customer-reapprove-checkbox" value="yes"<?php if(isset($general_options['reapprove_checkbox_default_value']) && $general_options['reapprove_checkbox_default_value'] == 'yes') echo 'checked="checked"';?>></input>
									<label class="wcam-label"  ><?php esc_html_e('Can customer change approval value after submit?', 'woocommerce-attach-me'); ?></label>
									<br/>
									<input type="checkbox" name="wcam-customer-feedback-checkbox[0]"  class="wcam-customer-feedback-checkbox" value="yes" <?php if(isset($general_options['feedback_checkbox_default_value']) && $general_options['feedback_checkbox_default_value'] == 'yes') echo 'checked="checked"';?>></input>
									<label class="wcam-label"  ><?php esc_html_e('Allow the customer to leave a feedback?', 'woocommerce-attach-me'); ?></label>
									<br/>
									<input type="checkbox" name="wcam-customer-cannot-modify-feedback-after-sumbit[0]"  class="wcam-customer-feedback-checkbox" value="yes" <?php if(isset($general_options['feedback_cannot_be_modified_after_submit_default_value']) && $general_options['feedback_cannot_be_modified_after_submit_default_value'] == 'yes') echo 'checked="checked"';?>></input>
									<label class="wcam-label"  ><?php esc_html_e('The feedback cannot be modified after submit', 'woocommerce-attach-me'); ?></label>
									<br/>
										<?php esc_html_e('... and feedback is required when (it works only if the previous feedback option has been enabled)', 'woocommerce-attach-me'); ?>
										<br/><select type="checkbox" name="wcam-customer-feedback-strategy[0]"  value="yes">
											<option value="always" <?php if(isset($general_options['feedback_strategy']) && $general_options['feedback_strategy'] == 'always') echo 'selected="selected"';?>><?php esc_html_e('Always', 'woocommerce-attach-me'); ?></option>
											<option value="only_yes" <?php if(isset($general_options['feedback_strategy']) && $general_options['feedback_strategy'] == 'only_yes') echo 'selected="selected"';?>><?php esc_html_e('If customer approves', 'woocommerce-attach-me'); ?></option>
											<option value="only_no" <?php if(isset($general_options['feedback_strategy']) && $general_options['feedback_strategy'] == 'only_no') echo 'selected="selected"';?>><?php esc_html_e('If customer does not approve', 'woocommerce-attach-me'); ?></option>
											<option value="never" <?php if(isset($general_options['feedback_strategy']) && $general_options['feedback_strategy'] == 'never') echo 'selected="selected"';?>><?php esc_html_e('Never', 'woocommerce-attach-me'); ?></option>
										</select>
									<br/>
									<input type="checkbox" name="wcam-customer-admin-notification-checkbox[0]" class="wcam-customer-admin-notification-checkbox" value="yes" <?php if(isset($general_options['customer_admin_notification_checkbox_default_value']) && $general_options['customer_admin_notification_checkbox_default_value'] == 'yes') echo 'checked="checked"';?>></input>
									<label class="wcam-label"  ><?php esc_html_e('Receive an email when the customer approve or leaves a feedback? ', 'woocommerce-attach-me'); ?></label>
									<br/>
									<input type="checkbox" <?php if(isset($general_options['display_copy_to_clipboard_button']) && $general_options['display_copy_to_clipboard_button'] == 'yes') echo 'checked="checked"';?> name="wcam-display-copy-to-clipboard-button[0]"  value="yes"></input>
									<label class="wcam-label" ><?php esc_html_e('Display also the "Copy attached file url to clipboard" button next the "Download/View" button on Order details page?', 'woocommerce-attach-me'); ?></label>
									<br/>
									<input type="checkbox" <?php if(isset($general_options['download_only_if_disclaimer_has_been_accepted']) && $general_options['download_only_if_disclaimer_has_been_accepted'] == 'yes') echo 'checked="checked"';?> name="wcam-download-only-if-disclaimer-has-been-accepted[0]"  value="yes"></input>
									<label class="wcam-label" ><?php wcam_html_escape_allowing_special_tags(__('The attachment is downloadable only if the <strong>disclaimer</strong> has been accepted? (Disclaimer text can be setted in the General options and texts menu)', 'woocommerce-attach-me')); ?></label>
									<br/>	
									
									
									<h4><?php esc_html_e('Select for which order status the attachment has to be hidden', 'woocommerce-attach-me'); ?></h4>
									<?php 
									 
									 foreach((array)$order_statuses as $code => $status): 
										
										$hide_on_current_status= isset($general_options['order_attachment_hide_by_status']) && in_array($code, $general_options['order_attachment_hide_by_status']) ? true : false;
									 ?>
										<input type="checkbox" <?php if($hide_on_current_status) echo 'checked="checked"';?>
										   name="wcam-order-attachment-hide-by-status[0][]"  value="<?php echo $code; ?>"><?php esc_html_e('Hide on',''); ?> <?php echo $status ?></input>
										<br/>
									<?php endforeach; ?>
									<h4 class="wcam_email_downloads_table_options_title"><?php esc_html_e('My Account - Downloads table', 'woocommerce-attach-me'); ?></h4>
									<p class="wcam-downloads-table-custom-title-column-description"><?php wcam_html_escape_allowing_special_tags(__('These options will take effect only if you enabled the <strong>Show attachments in Download tab</strong> via the <strong>General options & texts</strong> menu.', 'woocommerce-attach-me')); ?></p>
									<label class="wcam-label"  class="wcam-downloads-table-custom-title-column-input-label"><?php esc_html_e('Custom name (displayed in the "product" column)', 'woocommerce-attach-me'); ?></label>
									<input type="text" name="wcam-downloads-table-custom-title-column[0]" value="" class="wcam-downloads-table-custom-title-column-input"></input>
									<br/>
									<input type="checkbox" name="wcam-downloads-table-hide[0]"  value="yes" ></input>
									<label class="wcam-label"  ><?php esc_html_e('Hide from the downloads table', 'woocommerce-attach-me'); ?></label>
									<br/>
									
									<h4 class="wcam_email_attachments_title"><?php esc_html_e('Email attachments (attachments will not work with external file/url)', 'woocommerce-attach-me'); ?></h4>
									<input type="checkbox" class="wcam-attach-file-to-complete-order-email" name="wcam-attach-file-to-processing-order-email[0]"  value="yes" <?php if(isset($general_options['attach_file_to_processing_order_email_default_value']) && $general_options['attach_file_to_processing_order_email_default_value'] == 'yes') echo 'checked="checked"';?>></input>
									<label class="wcam-label"  ><?php esc_html_e('Attach file to the Processing order email', 'woocommerce-attach-me'); ?></label>
									<br/>
									<input type="checkbox" class="wcam-attach-file-to-complete-order-email" name="wcam-attach-file-to-complete-order-email[0]"  value="yes" <?php if(isset($general_options['attach_file_to_complete_order_email_default_value']) && $general_options['attach_file_to_complete_order_email_default_value'] == 'yes') echo 'checked="checked"';?>></input>
									<label class="wcam-label"  ><?php esc_html_e('Attach file to the Complete order email', 'woocommerce-attach-me'); ?></label>
									<br/>
									<input type="checkbox" class="wcam-attach-file-to-complete-order-email" name="wcam-attach-file-to-customer-invoice-email[0]"  value="yes" <?php if(isset($general_options['attach_file_to_customer_invoice_email_default_value']) && $general_options['attach_file_to_customer_invoice_email_default_value'] == 'yes') echo 'checked="checked"';?>></input>
									<label class="wcam-label"  ><?php esc_html_e('Attach file to the Customer Invoice email', 'woocommerce-attach-me'); ?></label>
									<br/>
									<input type="checkbox" class="wcam-attach-file-to-complete-order-email" name="wcam-attach-file-to-order-refunded-email[0]"  value="yes" <?php if(isset($general_options['attach_file_to_order_refunded_email_default_value']) && $general_options['attach_file_to_order_refunded_email_default_value'] == 'yes') echo 'checked="checked"';?>></input>
									<label class="wcam-label"  ><?php esc_html_e('Attach file to the Order Refunded email', 'woocommerce-attach-me'); ?></label>
									<br/>
									<?php if(!empty($custom_order_status_emails)): 
										 foreach($custom_order_status_emails as $wc_custom_email_id => $wc_custom_email_title): ?>
										<input type="checkbox" class="wcam-attach-file-to-complete-order-email" name="wcam_wc_custom_order_emails_attachment[0][<?php echo $wc_custom_email_id; ?>]"  value="yes" <?php if(isset($general_options['attach_file_to_'.$wc_custom_email_id]) && $general_options['attach_file_to_'.$wc_custom_email_id] == 'yes') echo 'checked="checked"';?>></input>
										<label class="wcam-label"  ><?php esc_html_e('Attach file to the', 'woocommerce-attach-me'); ?> <?php echo $wc_custom_email_title; ?> <?php esc_html_e('Email', 'woocommerce-attach-me'); ?></label>
										<br/>
										<?php endforeach; ?>
									<?php endif; ?>
									
									<h4 class="wcam_expiration_strategy_title"><?php esc_html_e('Expires?', 'woocommerce-attach-me'); ?></h4>
									<p><?php esc_html_e('If enabled will automatically enable the "Secure download" options. It is required to make this feature to properly work.', 'woocommerce-attach-me'); ?></p>
									<select class="wcam_expiration_strategy" name="wcam_expiration_strategy[0]" id="wcam_expiration_strategy_0" data-id="0">
										<option value="never"><?php esc_html_e('Never', 'woocommerce-attach-me'); ?></option>
										<option value="specific_date"><?php esc_html_e('At specific date', 'woocommerce-attach-me'); ?></option>
										<option value="relative_date"><?php esc_html_e('After the selected time amount after order date', 'woocommerce-attach-me'); ?></option>
									</select>
									
									<div id="wcam_expiration_relative_time_amout_selection_box_0" class="wcam_expiration_relative_time_amout_selection_box">
										<label class="wcam-label" ><?php esc_html_e('Time amount: ', 'woocommerce-attach-me'); ?></label>
										<input type="number" min="1" step="1" name="wcam_expiration_relative_time_amount[0]" value="1"></input>
										
										<label class="wcam-label"  class="wcam_expiration_relative_time_time_type_label"><?php esc_html_e('Time type: ', 'woocommerce-attach-me'); ?></label>
										<select class="wcam_expiration_strategy" name="wcam_expiration_relative_time_type[0]" data-id="0">
											<option value="second"><?php esc_html_e('Seconds', 'woocommerce-attach-me'); ?></option>
											<option value="minute"><?php esc_html_e('Minutes', 'woocommerce-attach-me'); ?></option>
											<option value="hour"><?php esc_html_e('Hours', 'woocommerce-attach-me'); ?></option>
											<option value="day"><?php esc_html_e('Days', 'woocommerce-attach-me'); ?></option>
											<option value="month"><?php esc_html_e('Months', 'woocommerce-attach-me'); ?></option>
										</select>
									</div>
									
									<div id="wcam_expiration_specific_date_selection_box_0" class="wcam_expiration_specific_date_selection_box">
										<label class="wcam-label" ><?php esc_html_e('Date and time: ', 'woocommerce-attach-me'); ?></label>
										<input type="text" class="wcam_expiration_specific_date" name="wcam_expiration_specific_date[0]" ></input>
									</div>
									
								</div>
								<button style="display:block; margin-top:15px;" class="button delete_button" data-fileid="0" onclick="wcam_remove_field(event);" ><?php esc_html_e('Delete', 'woocommerce-attach-me'); ?></button>
							</div>
						</li>
			<?php else:
			?>
			<div id="wcam-edit-box">
			 <?php foreach((array)$attachments_meta as $attachment_meta): 
				if(!isset($attachment_meta['id']))
						continue;
			 $counter = $attachment_meta['id']; 
			 $max_id = $max_id < $counter ? $counter : $max_id;
			 $is_external_link = (!isset($attachment_meta['absolute_path']) && !isset($attachment_meta['media_id']))? "yes":"no";
			 $is_expired = $wcam_order_model->is_attachment_expired($attachment_meta, WCAM_Order::get_date_created($wc_order));
			 $is_expired_title = $is_expired ? esc_html__('Yes', 'woocommerce-attach-me') : esc_html__('No', 'woocommerce-attach-me');
			?>
				<li class="wcam-attachment-box" data-id="<?php echo $counter; ?>" data-already-uploaded="yes" data-is-external="<?php echo $is_external_link;?>">
					<h2><div class="button wcam_collapse_expand_button" data-id="<?php echo $counter; ?>">+</div><?php esc_html_e('#', 'woocommerce-attach-me'); ?><?php echo $counter; ?> <?php if(isset($attachment_meta['title'])) echo " - ".$attachment_meta['title']. " - ".esc_html__('Is expired: ', 'woocommerce-attach-me').$is_expired_title; ?></h2>
					<div style="display:none;" class="wcam-attachment-box-content" id="wcam-attachment-box-content-<?php echo $counter; ?>" data-already-collapsed="yes">
						<h4 class='attachment-box-title' id="wcam_attachment_title_<?php echo $counter; ?>"><?php esc_html_e('Title', 'woocommerce-attach-me');?></h4>
						<p class='attachment-box-option-description real-title' id="real-title-<?php echo $counter; ?>"><?php if(!empty($attachment_meta['title'])) echo $attachment_meta['title']; else esc_html_e('No title', 'woocommerce-attach-me');?></p>
						<?php 
							
							$file_name = isset($attachment_meta['absolute_path']) && $attachment_meta['absolute_path'] != "" ? $attachment_meta['absolute_path'] : $attachment_meta['url'];
							echo "<h4 class='attachment-box-title'>".esc_html__('File name', 'woocommerce-attach-me')."</h4>";
							echo "<p class='attachment-box-option-description'>".basename($file_name)."</p>";
							
							if(isset($attachment_meta['description']) && trim($attachment_meta['description']) != "")
							{
								echo "<h4 class='attachment-box-title'>".esc_html__('Description', 'woocommerce-attach-me')."</h4>";
								echo "<p class='attachment-box-option-description'>";
								echo $attachment_meta['description'];
								echo "</p>";
							}
							//if(isset($attachment_meta['secure-download']))
							{
								$secure_download = isset($attachment_meta['secure-download']) && $attachment_meta['secure-download'] == "yes" ? esc_html__('Enabled', 'woocommerce-attach-me'): esc_html__('Disabled', 'woocommerce-attach-me');
								echo '<h4 class="attachment-box-title">'.esc_html__('Secure download', 'woocommerce-attach-me').'</h4>';
								echo '<p class="attachment-box-option-description">'.$secure_download.'</p>';
							}
							if(isset($attachment_meta['expiration-strategy']))
							{
								 $is_expired_string = $is_expired ? '<span style="color:red">'.esc_html__('Yes', 'woocommerce-attach-me').'</span>' : '<span style="color:green">'.esc_html__('No', 'woocommerce-attach-me').'</span>';
								
								echo "<h4 class='attachment-box-title'>".esc_html__('Expiration', 'woocommerce-attach-me')."</h4>";
								echo '<p class="attachment-box-option-description">';
								switch($attachment_meta['expiration-strategy'])
								{
									case 'never': esc_html_e('Never', 'woocommerce-attach-me'); break;
									case 'specific_date': echo "<strong>".esc_html__('Is expired: ', 'woocommerce-attach-me')."</strong>".$is_expired_string." - ".esc_html__('Expiration date: ', 'woocommerce-attach-me').$wcam_order_model->get_attachment_expiration_date($order_id, $attachment_meta); break;
									case 'relative_date': echo "<strong>".esc_html__('Is expired: ', 'woocommerce-attach-me')."</strong>".$is_expired_string." - ".esc_html__('Expiration date: ', 'woocommerce-attach-me').$wcam_order_model->get_attachment_expiration_date($order_id, $attachment_meta); break;
								} 
								echo '</p>';
							}
							if(isset($attachment_meta['customer-has-to-be-approved']) && $attachment_meta['customer-has-to-be-approved'] == 'yes')
							{
								echo "<h4 class='attachment-box-title'>".esc_html__('Approval status', 'woocommerce-attach-me')."</h4>";
								echo '<p class="attachment-box-option-description">';
								if(!isset($attachment_meta['customer-has-approved']) || $attachment_meta['customer-has-approved'] == 'none')
									echo '<h5 style="color:grey">'.esc_html__('Waiting for customer approval', 'woocommerce-attach-me').'</h5>';
								else if($attachment_meta['customer-has-approved'] == 'yes')
									echo '<h5 style="color:green">'.esc_html__('Customer has approved', 'woocommerce-attach-me').'</h5>';
								else
									echo '<h5 style="color:red">'.esc_html__('Customer has not approved', 'woocommerce-attach-me').'</h5>';
								echo '</p>';
								
								$approval_date = wcam_get_value_if_set($attachment_meta, 'approval-date', "");
								$approval_date = $approval_date != "" ?  $wcam_time_model->format_date_according_wp_settings($approval_date) : esc_html__(' - ', 'woocommerce-attach-me');
								echo "<h4 class='attachment-box-title'>".esc_html__('Approved / Not approved on', 'woocommerce-attach-me')."</h4>";
								echo "<p>".$approval_date."</p>";
								
								echo "<h4 class='attachment-box-title'>".esc_html__('Direct link for approval', 'woocommerce-attach-me')."</h4>";
								echo '<p class="attachment-box-option-description">'.add_query_arg(array('view-order'=> $order_id, 
																										  'wcam_save_customer_feedbacks' => 'yes',
																										  'wcam_attachment_id['.$counter.']' => $counter,
																										  'wcam_customer_approval['.$counter.']' =>'yes'),																									
																									get_permalink( get_option( 'woocommerce_myaccount_page_id' ) )  ).'</p>';
								
							}
							if(isset($attachment_meta['customer-can-reapprove']))
							{
								$value = $attachment_meta['customer-can-reapprove'] == 'yes' ? esc_html__('Yes','woocommerce-attach-me') : esc_html__('No','woocommerce-attach-me');
								echo '<h4 class="attachment-box-title">'.esc_html__('Can customer change approval value after submit','woocommerce-attach-me').'</h4>';
								echo '<p class="attachment-box-option-description">'.$value.'</p>';
							}
							if(isset($attachment_meta['customer-feedback-enabled']) && $attachment_meta['customer-feedback-enabled']=='yes')
							{
								$feedback = isset($attachment_meta['customer-feedback']) ? $attachment_meta['customer-feedback']:" ";
								echo '<h4 class="attachment-box-title">'.esc_html__('Feedback', 'woocommerce-attach-me').'</h4>';
								echo '<p class="attachment-box-option-description">'.$feedback.'</p>';
								
								$feedback_can_be_modified = wcam_get_value_if_set($attachment_meta, 'customer-feedback-cannot-be-modified-after-submit', 'no') == 'no' ? esc_html__('Yes','woocommerce-attach-me') : esc_html__('No','woocommerce-attach-me');
								echo '<h4 class="attachment-box-title">'.esc_html__('The feedback can be modified after submit', 'woocommerce-attach-me').'</h4>';
								echo '<p class="attachment-box-option-description">'.$feedback_can_be_modified.'</p>';
								
								$feedback_strategy = isset($attachment_meta['customer-feedback-strategy']) ? $attachment_meta['customer-feedback-strategy']:"none";
								switch($feedback_strategy)
								{
									case 'none': $feedback_strategy = esc_html__('Never','woocommerce-attach-me'); break;
									case 'always': $feedback_strategy = esc_html__('Always','woocommerce-attach-me'); break;
									case 'only_yes': $feedback_strategy = esc_html__('Only If customer approves','woocommerce-attach-me'); break;
									case 'only_no': $feedback_strategy = esc_html__('Only If customer does not approve','woocommerce-attach-me'); break;
									case 'never': $feedback_strategy = esc_html__('Never','woocommerce-attach-me'); break;
								}
								echo '<h4 class="attachment-box-title">'.esc_html__('Feedback strategy', 'woocommerce-attach-me').'</h4> ';
								echo '<p class="attachment-box-option-description">'.$feedback_strategy.'</p>';
							}
						
							if(isset($attachment_meta['order-attachment-hide-by-status']) && !empty($attachment_meta['order-attachment-hide-by-status']))
							{
								$order_statuses = wc_get_order_statuses();
								echo '<h4 class="attachment-box-title">'.esc_html__('Hide attachment for order status', 'woocommerce-attach-me').'</h4>';
								echo '<ol>';
								foreach((array)$order_statuses as $code => $status)
								{
									$hide_on_current_status = in_array($code, $attachment_meta['order-attachment-hide-by-status']) ? true : false;
									if($hide_on_current_status)
										echo '<li> '.$status.'</li>';
								}
								echo '</ol>';
							}
							if(isset($attachment_meta['customer-admin-notification']))
							{
								$admin_email_notofication = $attachment_meta['customer-admin-notification'] == "yes" ? esc_html__('Enabled', 'woocommerce-attach-me'): esc_html__('Disabled', 'woocommerce-attach-me');
								echo '<h4 class="attachment-box-title">'.esc_html__('Admin notification', 'woocommerce-attach-me').'</h4>';
								echo '<p class="attachment-box-option-description">'.$admin_email_notofication.'</p>';
							}
							if(isset($attachment_meta['attach-file-to-processing-order-email']))
							{
								$attach_file_to_processing_order_email = $attachment_meta['attach-file-to-processing-order-email'] == "yes" ? esc_html__('Enabled', 'woocommerce-attach-me'): esc_html__('Disabled', 'woocommerce-attach-me');
								echo '<h4 class="attachment-box-title">'.esc_html__('Attach file to processing order email', 'woocommerce-attach-me').'</h4>';
								echo '<p class="attachment-box-option-description">'.$attach_file_to_processing_order_email.'</p>';
							}
							if(isset($attachment_meta['attach-file-to-complete-order-email']))
							{
								$attach_file_to_complete_order_email = $attachment_meta['attach-file-to-complete-order-email'] == "yes" ? esc_html__('Enabled', 'woocommerce-attach-me'): esc_html__('Disabled', 'woocommerce-attach-me');
								echo '<h4 class="attachment-box-title">'.esc_html__('Attach file to complete order email', 'woocommerce-attach-me').'</h4>'; 
								echo '<p class="attachment-box-option-description">'.$attach_file_to_complete_order_email.'</p>';
							}
							if(isset($attachment_meta['attach-file-to-customer-invoice-email']))
							{
								$attach_file_to_customer_invoice_email = $attachment_meta['attach-file-to-customer-invoice-email'] == "yes" ? esc_html__('Enabled', 'woocommerce-attach-me'): esc_html__('Disabled', 'woocommerce-attach-me');
								echo '<h4 class="attachment-box-title">'.esc_html__('Attach file to customer invoice email', 'woocommerce-attach-me').'</h4>'; 
								echo '<p class="attachment-box-option-description">'.$attach_file_to_customer_invoice_email.'</p>';
							}	
							if(isset($attachment_meta['attach-file-to-order-refunded-email']))
							{
								$attach_file_to_customer_invoice_email = $attachment_meta['attach-file-to-order-refunded-email'] == "yes" ? esc_html__('Enabled', 'woocommerce-attach-me'): esc_html__('Disabled', 'woocommerce-attach-me');
								echo '<h4 class="attachment-box-title">'.esc_html__('Attach file to order refunded email', 'woocommerce-attach-me').'</h4>'; 
								echo '<p class="attachment-box-option-description">'.$attach_file_to_customer_invoice_email.'</p>';
							}	
							
							if(!empty($custom_order_status_emails))
							{
								echo '<h4 class="attachment-box-title">'.esc_html__('Email attachment', 'woocommerce-attach-me').'</h4>';
								echo '<ol>';
								foreach($custom_order_status_emails as $wc_custom_email_id => $wc_custom_email_title)
								 {
									$attach_file_to_customer_invoice_email = isset($attachment_meta['wc_custom_order_emails_attachment'][ $wc_custom_email_id]) &&  $attachment_meta['wc_custom_order_emails_attachment'][ $wc_custom_email_id] == "yes" ? esc_html__('Enabled', 'woocommerce-attach-me'): esc_html__('Disabled', 'woocommerce-attach-me');
									echo '<li><strong>'.sprintf(__('Attach file %s email', 'woocommerce-attach-me'), $wc_custom_email_title).':</strong> '.$attach_file_to_customer_invoice_email.'</li>';
						
								 }
								 echo '</ol>';
							}
							if(isset($attachment_meta['download-only-if-disclaimer-has-been-accepted']))
							{
								$show_disclaimer = $attachment_meta['download-only-if-disclaimer-has-been-accepted'] == "yes" ? esc_html__('Yes', 'woocommerce-attach-me'): esc_html__('No', 'woocommerce-attach-me');
								echo '<h4 class="attachment-box-title">'.esc_html__('User can download only if disclaimer has been accepted', 'woocommerce-attach-me').'</h4>';
								echo '<p class="attachment-box-option-description">'.$show_disclaimer.'</p>';
								
								$disclaimer_has_been_accepted = isset($attachment_meta['disclaimer-has-been-accepted-by-user']) ? esc_html__('Yes', 'woocommerce-attach-me') : esc_html__('No', 'woocommerce-attach-me');
								echo '<h4 class="attachment-box-title">'.esc_html__('Disclaimer has been accepted by user', 'woocommerce-attach-me').'</h4>';
								echo '<p class="attachment-box-option-description">'.$disclaimer_has_been_accepted.'</p>';
							}
							
							$downloads_table_custom_product_title = isset($attachment_meta['downloads-table-custom-title-column']) && $attachment_meta['downloads-table-custom-title-column'] != "" ? $attachment_meta['downloads-table-custom-title-column'] : esc_html__('Using default', 'woocommerce-attach-me');
							echo '<h4 class="attachment-box-title">'.esc_html__('My Account - Downloads table - Custom product title', 'woocommerce-attach-me').'</h4>';
							echo '<p class="attachment-box-option-description">'.$downloads_table_custom_product_title.'</p>';
							
							$downloads_table_hide = wcam_get_value_if_set($attachment_meta, 'downloads-table-hide', "no") == 'yes' ? esc_html__('Yes', 'woocommerce-attach-me') : esc_html__('No', 'woocommerce-attach-me');
							echo '<h4 class="attachment-box-title">'.esc_html__('My Account - Downloads table - Hide from the table', 'woocommerce-attach-me').'</h4>';
							echo '<p class="attachment-box-option-description">'.$downloads_table_hide.'</p>';
								
							$number_od_downloads = isset($attachment_meta['number_of_donwloads']) ? $attachment_meta['number_of_donwloads'] : 0;
							echo '<h4 class="attachment-box-title">'.esc_html__('Number of downloads (counter works only for secure links)', 'woocommerce-attach-me').'</h4>';
							echo '<p class="attachment-box-option-description">'.$number_od_downloads.'</p>';
							
							
							
							echo '<h4 class="attachment-box-title">'.esc_html__('Attachment URL', 'woocommerce-attach-me').'</h4>';
							echo '<p class="attachment-box-option-description">'.$attachment_meta['url'].'</p>';
							
							echo '<h4 class="attachment-box-title">'.esc_html__('Order page URL', 'woocommerce-attach-me').'</h4>';
							echo '<p class="attachment-box-option-description">'.add_query_arg('view-order', $order_id, get_permalink( get_option( 'woocommerce_myaccount_page_id' ) )  ).'</p>';
																				
						  ?>
					
						<h4 class="attachment-box-title"><?php esc_html_e('Shortcode', 'woocommerce-attach-me'); ?></h4>
						<p>
						<a href="#" class="wcam_tooltip">
									[wcam_download_link id="<?php echo $counter; ?>"]
									<span>
										<?php esc_html_e('Paste the following shortcode ', 'woocommerce-attach-me'); ?> <b>[wcam_download_link id="<?php echo $counter; ?>"]</b>  <?php esc_html_e('in the notification email body (see down below) to embed a direct link to download/view the file.', 'woocommerce-attach-me'); ?>
									</span>
								</a>
						</p>
						<a target="_blank" class="button button-primary wcam_primary_button" style="text-decoration:none; color:white;" href="<?php echo $attachment_meta['url']; ?>"><?php esc_html_e('Download / View', 'woocommerce-attach-me'); ?></a>
						<button class="button button-primary wcam_primary_button wcam_copy_to_clipboard" style="text-decoration:none; color:white;" data-url="<?php echo $attachment_meta['url']; ?>"><?php esc_html_e('Copy link to clipboard', 'woocommerce-attach-me'); ?></button>
						<input type="submit" class="button delete_button" data-fileid="<?php echo $attachment_meta['id'] ?>" value="<?php esc_html_e('Delete', 'woocommerce-attach-me'); ?>" onclick="wcam_remove_field(event);" ></input>
					</div>
				</li>
			  <?php endforeach;?>
		     </div>
			<?php endif; ?>
			</ul>
			<button style="margin-top:15px;" class="button button-primary wcam_primary_button" onclick="wcam_add_field(event);" ><?php esc_html_e('Add more', 'woocommerce-attach-me'); ?></button>
			
			<h2 id="wcam-notification-title"><?php esc_html_e('Notification & Link embedding', 'woocommerce-attach-me'); ?></h2>
			<div id="wcam-notify-box">
			<?php 
			//if $wcam_options['embed-links-to-complete-mail'] == no, user has unchecked, otherwise if not setted can be override by default setting
			//Default options managment
			if(!isset($wcam_options['embed-links-to-complete-mail'] ) && isset($general_options['embed_links_to_complete_mail']) && $general_options['embed_links_to_complete_mail'] == 'yes')
			{
				$wcam_options['embed-links-to-complete-mail'] = 'yes';
				
				if(isset($general_options['embed_links_hide_by_status']))
					$wcam_options['embed-links-hide-by-status'] = $general_options['embed_links_hide_by_status'];
				if(isset($general_options['embed_links_preset_email_text_id']))
					$wcam_options['embed-links-preset-email-text-id'] = $general_options['embed_links_preset_email_text_id'];
				if(isset($general_options['embed_links_preset_email_text']) && isset($general_options['embed_links_preset_email_text'][$order_lang]) && $general_options['embed_links_preset_email_text'][$order_lang] != "" && (!isset($general_options['embed_links_preset_email_text_id']) || $general_options['embed_links_preset_email_text_id'] == 'input_text'))
					$wcam_options['embed-links-to-complete-mail-text'] = $general_options['embed_links_preset_email_text'][$order_lang];
			}
			?>
			<input type="checkbox" name="wcam-embed-links-to-complete-mail" id="wcam-embed-links-checkbox" <?php if(isset($wcam_options['embed-links-to-complete-mail']) && $wcam_options['embed-links-to-complete-mail'] == 'yes') {echo 'value="yes" checked="checked"';} else echo 'value="no"'; ?> ></input>
			<label class="wcam-label"  for="wcam-embed-links-to-complete-email-checkbox"><?php esc_html_e('Embed download/view links to WooCommerce emails?', 'woocommerce-attach-me'); ?></label>
			<div id="wcam-embed-link-subbox" style="display:none; clear:both; margin-top:10px;">
				<label class="wcam-label" ><?php esc_html_e('If embedding option is enable by default links are embedded to ALL outgoing WooCommerce order notification emails. However the embedding can be disable according to the current order status:', 'woocommerce-attach-me'); ?></label><br/> 
				<?php foreach((array)$order_statuses as $code => $status): ?>
					<input type="checkbox" <?php if(isset($wcam_options['embed-links-hide-by-status']) && in_array($code, $wcam_options['embed-links-hide-by-status'])) echo 'checked="checked"'; ?>
					   name="wcam-embed-links-hide-by-status[]"  value="<?php echo $code; ?>" ><?php esc_html_e('Hide for',''); ?> <?php echo $status ?></input>
					<br/>
				<?php endforeach; ?>
				<br/><br/> 					
				<label class="wcam-label" ><?php esc_html_e('Preset body', 'woocommerce-attach-me'); ?></label><br/> 
				<p class="wcam_instruction_paragraph">
					<?php esc_html_e('You can use as message body a preset text. Use the following dropdown menu to choose which preset text to load:', 'woocommerce-attach-me'); ?>
				<br/> 	
				<select name="wcam-embed-links-preset-email-text-id" id="wcam_load_preset_embedded_email" data-id="wcam-embed-links-to-complete-mail-text">
					<option value="input_text" <?php if(isset($wcam_options['embed-links-preset-email-text-id']) && $wcam_options['embed-links-preset-email-text-id'] == 'input_text') echo 'selected="selected"'; ?>><?php esc_html_e('Use input text', 'woocommerce-attach-me'); ?></option>
					<?php 
						$preset_email_texts = $general_options_model->get_emails_preset_texts();
						foreach((array)$preset_email_texts as $text_data): ?>
							<option value="<?php echo $text_data['body_text_unique_field_id']; ?>" <?php if(isset($wcam_options['embed-links-preset-email-text-id']) && $wcam_options['embed-links-preset-email-text-id'] == $text_data['body_text_unique_field_id']) echo 'selected="selected"'; ?> ><?php echo $text_data['body_text_title']; ?></option>
						<?php endforeach; ?>
				</select>
				</p>
				<br/>
				<label class="wcam-label"  for="wcam-embed-links-to-complete-mail-text"><?php esc_html_e('The following text will be included in the WooCommerce emails','woocommerce-attach-me');?></label>
				<p class="wcam_instruction_paragraph">
					<?php wcam_html_escape_allowing_special_tags(__('Use the <span class="wcam_highlight_text">[wcam_order_page_link]</span> to embed a link to the order page. To customize link text use the following format: <span class="wcam_highlight_text">[wcam_order_page_link]Custom link text[/wcam_order_page_link]</span>.<br/>Use the attachments download/view shortcodes to link the attachment. Ex.: Download your <span class="wcam_highlight_text">[wcam_download_link id="0"]invoice[/wcam_download_link]</span> and <span class="wcam_highlight_text">[wcam_download_link id="1"]digital manual[/wcam_download_link]</span>. You can also use the following shortcodes: <span class="wcam_highlight_text">[order_id]</span>, <span class="wcam_highlight_text">[order_date_created]</span>, <span class="wcam_highlight_text">[billing_first_name]</span>, <span class="wcam_highlight_text">[billing_last_name]</span>, <span class="wcam_highlight_text">[billing_company]</span>, <span class="wcam_highlight_text">[billing_address_1]</span>, <span class="wcam_highlight_text">[billing_address_2]</span>, <span class="wcam_highlight_text">[billing_city]</span>, <span class="wcam_highlight_text">[billing_state]</span> ,<span class="wcam_highlight_text">[billing_country]</span>, <span class="wcam_highlight_text">[billing_postcode]</span>, <span class="wcam_highlight_text">[billing_email]</span>, <span class="wcam_highlight_text">[billing_phone]</span>, <span class="wcam_highlight_text">[shipping_first_name]</span>, <span class="wcam_highlight_text">[shipping_last_name]</span>, <span class="wcam_highlight_text">[shipping_company]</span>, <span class="wcam_highlight_text">[shipping_address_1]</span>, <span class="wcam_highlight_text">[shipping_address_2]</span>, <span class="wcam_highlight_text">[shipping_city]</span>, <span class="wcam_highlight_text">[shipping_state]</span> ,<span class="wcam_highlight_text">[shipping_country]</span> and <span class="wcam_highlight_text">[shipping_postcode]</span>.<br/><br/>If you want to use headings, note that the <span class="wcam_highlight_text">h3</span> is the default tile tag used in WooCoommerce emails. ', 'woocommerce-attach-me')); ?>
				</p>
				<textarea rows="4" cols="30" id="wcam-embed-links-to-complete-mail-text" name="wcam-embed-links-to-complete-mail-text" class="wcam-embed-link" placeholder="<?php esc_html_e('Ex.: To view, click on the follow link [wcam_download_link]', 'woocommerce-attach-me'); ?>" name="wcam-complete-order-email-text">
					<?php if(isset($wcam_options['embed-links-to-complete-mail-text'])) echo  stripcslashes($wcam_options['embed-links-to-complete-mail-text']); ?>
				</textarea>
			</div>			
			<br/>
			<input type="checkbox" name="wcam-notify-via-mail" id="wcam-notify-checkbox" value="no"></input>
			<label class="wcam-label"  for="wcam-notify-checkbox"><?php esc_html_e('Send a notification email to the customer? (Hitting the save button will send the email)', 'woocommerce-attach-me'); ?></label>
				<div id="wcam-notify-subbox" style="display:none; clear:both; margin-top:10px;">
					<h4 class="wcam_instruction_title"><?php esc_html_e('Recipients. By default, is the billing email address.', 'woocommerce-attach-me'); ?></h4>
					<p class="wcam_instruction_paragraph">
						<?php wcam_html_escape_allowing_special_tags(__('By default, the email is sent to the billing email. You can send to multiple addresses by separating email with the "," character.', 'woocommerce-attach-me')); ?>
						<input type="text" placeholder="<?php esc_html_e('Ex.: email1@domain.com, email2@domain.com', 'woocommerce-attach-me'); ?>" id="wcam-notification-recipient" name="wcam-notification-recipient" value="<?php echo $wc_order->get_billing_email(); ?>"></input>
					</p>				
					
					<h4 class="wcam_instruction_title"><?php esc_html_e('Subject', 'woocommerce-attach-me'); ?></h4>
					<p class="wcam_instruction_paragraph">
						<?php wcam_html_escape_allowing_special_tags(__('You can use the <span class="wcam_highlight_text">[order_id]</span> shortcode.', 'woocommerce-attach-me')); ?>
						<input type="text" placeholder="<?php esc_html_e('Ex.: New Invoice', 'woocommerce-attach-me'); ?>" id="wcam-notification-subject" name="wcam-notification-subject" value="<?php echo wcam_get_value_if_set($general_options, array("manual_notification_default_subject", $curr_lang), "");?>"></input>
					</p>
					<h4 class="wcam_instruction_title"><?php esc_html_e('Attachments', 'woocommerce-attach-me'); ?></h4>
						<p class="wcam_instruction_paragraph"><small><?php wcam_html_escape_allowing_special_tags(__('Only uploaded files and files from media gallery can be attacched to the notificaton email. If you have just created an attachment, you need to save and then you will be able to attach it.<br/>Remember that some some server email provider will not receive emails with attachments bigger than 10MB (<a target="_blank" href="https://www.outlook-apps.com/maximum-email-size/">Gmail: 25MB, Outlook and Hotmail 10MB,...</a>)', 'woocommerce-attach-me')); ?></small></p>
					<select id="wcam-attachment-ids" multiple="multiple">
					<?php if(isset($general_options['manual_notification_select_all_attachments']))
					{
						/*  Noo need, triggered via js
							foreach((array)$attachments_meta as $attachment_meta)
							if(isset($attachment_meta['id']))
								echo '<option value="'.$attachment_meta['id'].'" selected="selected">'.$attachment_meta['title'].'</option>'; */
					}						
					?>
					</select> 
					<br/>
					<h4 class="wcam_instruction_title"><?php esc_html_e('Preset body', 'woocommerce-attach-me'); ?></h4>
					<p class="wcam_instruction_paragraph">
						<label class="wcam-label" ><?php esc_html_e('You can use as message body a preset text. Use the following dropdown menu to choose which preset text to load:', 'woocommerce-attach-me'); ?></label><br/> 
							<select name="wcam-notification-preset-email-text-id" id="wcam_load_preset_notification_email" data-id="wcam-message">
								<option value="input_text" <?php if(isset($wcam_options['notification-preset-email-text-id']) && $general_options['manual_notification_preset_body_id'] == 'input_text') echo 'selected="selected"'; ?>><?php esc_html_e('Select a preset text', 'woocommerce-attach-me'); ?></option>
								<?php 
									$preset_email_texts = $general_options_model->get_emails_preset_texts();
									foreach((array)$preset_email_texts as $text_data): ?>
										<option value="<?php echo $text_data['body_text_unique_field_id']; ?>" <?php if(isset($general_options['manual_notification_preset_body_id']) && $general_options['manual_notification_preset_body_id'] == $text_data['body_text_unique_field_id']) echo 'selected="selected"'; ?> ><?php echo $text_data['body_text_title']; ?></option>
									<?php endforeach; ?>
							</select>
					</p>
				
					<h4 class="wcam_instruction_title"><?php esc_html_e('Message', 'woocommerce-attach-me'); ?></h4>
					<p class="wcam_instruction_paragraph">
					<?php wcam_html_escape_allowing_special_tags(__('Use the <span class="wcam_highlight_text">[wcam_order_page_link]</span> to embed a link to the order page. To customize link text use the following format: <span class="wcam_highlight_text">[wcam_order_page_link]Custom link text[/wcam_order_page_link]</span>.<br/>Use the attachments download/view shortcodes to link the attachment. Ex.: Download your <span class="wcam_highlight_text">[wcam_download_link id="0"]invoice[/wcam_download_link]</span> and <span class="wcam_highlight_text">[wcam_download_link id="1"]digital manual[/wcam_download_link]</span>. You can also use the following shortcodes: <span class="wcam_highlight_text">[order_id]</span>, <span class="wcam_highlight_text">[order_date_created]</span>, <span class="wcam_highlight_text">[billing_first_name]</span>, <span class="wcam_highlight_text">[billing_last_name]</span>, <span class="wcam_highlight_text">[billing_company]</span>, <span class="wcam_highlight_text">[billing_address_1]</span>, <span class="wcam_highlight_text">[billing_address_2]</span>, <span class="wcam_highlight_text">[billing_city]</span>, <span class="wcam_highlight_text">[billing_state]</span> ,<span class="wcam_highlight_text">[billing_country]</span>, <span class="wcam_highlight_text">[billing_postcode]</span>, <span class="wcam_highlight_text">[billing_email]</span>, <span class="wcam_highlight_text">[billing_phone]</span>, <span class="wcam_highlight_text">[shipping_first_name]</span>, <span class="wcam_highlight_text">[shipping_last_name]</span>, <span class="wcam_highlight_text">[shipping_company]</span>, <span class="wcam_highlight_text">[shipping_address_1]</span>, <span class="wcam_highlight_text">[shipping_address_2]</span>, <span class="wcam_highlight_text">[shipping_city]</span>, <span class="wcam_highlight_text">[shipping_state]</span> ,<span class="wcam_highlight_text">[shipping_country]</span> and <span class="wcam_highlight_text">[shipping_postcode]</span>.<br/><br/>If you want to use headings, note that the <span class="wcam_highlight_text">h3</span> is the default tile tag used in WooCoommerce emails. ', 'woocommerce-attach-me')); ?>
				</p>
					<textarea rows="8" id="wcam-message" placeholder="<?php esc_html_e('Ex.: Order invoce is now available on order details page. To view, click on the follow link [wcam_download_link id=\"99999\"]', 'woocommerce-attach-me'); ?>" name="wcam-notification-message">
						<?php echo  nl2br(stripcslashes(wcam_get_value_if_set($general_options, array("manual_notification_preset_email_text", $curr_lang), ""))); ?>
					</textarea>
					<?php 
					// Text area adde via wp_editor doesn't work when dincamically addede via js:
					/* wp_editor( "", 'wcam-message', array(
						'wpautop'       => true,
						'media_buttons' => true,
						'textarea_name' => 'wcam-notification-message',
						'textarea_rows' => 8,
						'teeny'         => true
					) ); */
					?>
				</div>
			</div>
			<div class="wcam_spacer"></div>
			 <button class="button button-primary wcam_primary_button" id="wcam-save-button"><?php esc_html_e('Save', 'woocommerce-attach-me'); ?></button>
		</div>
	
		<div class="clear"></div>
		</div>
		
		<?php 
		
		
	}
	
}
?>