<?php
class WCAM_OrdersTableAddon
{
	public function __construct()
	{
		//HPOS 
		add_action( 'woocommerce_shop_order_list_table_custom_column', array($this, 'manage_attachment_counter_column'),10, 2 ); 
		add_filter( 'woocommerce_shop_order_list_table_columns', array($this, 'add_attachment_counter_column'), 15 ); 
		add_filter( 'handle_bulk_actions-woocommerce_page_wc-orders', array( &$this,'handle_delete_uploads_bulk_action'), 10, 3); 
		add_action('woocommerce_order_list_table_restrict_manage_orders', array( &$this,'add_attachments_select_box_filter'), 10, 2);
		add_filter('woocommerce_order_list_table_prepare_items_query_args', array( &$this,'filter_order_list_query'), 10, 2); 
		//
		add_action( 'manage_shop_order_posts_custom_column', array($this, 'manage_attachment_counter_column'), 10, 2 );				//Same for HPOS
		add_filter( 'manage_edit-shop_order_columns', array($this, 'add_attachment_counter_column'),15 ); 							//Same for HPOS
		add_action('restrict_manage_posts', array( &$this,'add_attachments_select_box_filter'));									//Slightly modified for HPOS
		add_filter('parse_query',array( &$this,'filter_query_by_attachments')); 													//For HPOS managed by filter_order_list_query
		add_action('admin_enqueue_scripts', array( &$this,'add_bulk_delete_attachments_action'));									//Slightly modified for HPOS
		add_action('load-edit.php', array( &$this,'delete_attachments_bulk_action'));												//For HPOS managed by handle_delete_uploads_bulk_action()
		add_action('admin_notices', array( &$this,'delete_attachments_admin_notices'));												//Slightly modified for HPOS
	}
	
 
	function add_bulk_delete_attachments_action($hook) 
	{
	  global $post_type;
	 $screen = get_current_screen(); 
	  if($post_type == 'shop_order'  || /* HPOS*/ wcam_get_value_if_set($_REQUEST,'page',false) == 'wc-orders'  ) 
	  {
		wp_register_script('wcam-backend-order-table',  wcam_PLUGIN_PATH . '/js/wcam-backend-order-table.js', array( 'jquery' ));
		$js_params = array(
				'delete_attachment_msg' => esc_html__('Delete attachments', 'woocommerce-attach-me')
				);
		wp_localize_script( 'wcam-backend-order-table', 'wcam_order_table', $js_params );
		wp_enqueue_script( 'wcam-backend-order-table' );
		
	  }
	}
	//HPOS
	public function handle_delete_uploads_bulk_action($redirect_to, $action, $ids)
	{
		global $wcam_file_model;
		
		switch($action) 
		{
			// 3. Perform the action
			case 'wcam_delete_attachments':
			  $deleted = 0;
			  $order_ids =  is_array($ids) ? $ids : array();
			  foreach( $order_ids as $order_id ) 
			  {
				$wcam_file_model->delete_all_order_attachments($order_id);
				$deleted++;
			  }

			  $redirect_to .= "&wcam_deleted={$deleted}&ids=". join(',', $order_ids);
			break;
			default: return;
		}
		
		return $redirect_to;
	}
	function delete_attachments_bulk_action() 
	{
	  global $wcam_file_model;
	  $wp_list_table = _get_list_table('WP_Posts_List_Table');
	  $action = $wp_list_table->current_action();
	
	  switch($action) 
	  {
		// 3. Perform the action
		case 'wcam_delete_attachments':
		  $deleted = 0;
		  $post_ids = $_GET['post'];
		  foreach( $post_ids as $order_id ) {
			$wcam_file_model->delete_all_order_attachments($order_id);
			$deleted++;
		  }
	 
		  $sendback = add_query_arg( array('wcam_deleted' => $deleted, 'post_type'=>'shop_order', 'ids' => join(',', $post_ids) ), $sendback );
	 
		break;
		default: return;
	  }
	 
	  wp_redirect($sendback);
	 
	  exit();
	}
	
 
	function delete_attachments_admin_notices($args = null) 
	{
	  global $post_type, $pagenow;
	
	  if( (($pagenow == 'edit.php' && $post_type == 'shop_order') || /* HPOS*/ wcam_get_value_if_set($_REQUEST,'page',false) == 'wc-orders'  ) &&
		 isset($_REQUEST['wcam_deleted']) && (int) $_REQUEST['wcam_deleted']) 
		 {
		   $message = sprintf( _n( 'Order attachments deleted.', '%s orders attachments deleted.', $_REQUEST['wcam_deleted'] ), number_format_i18n( $_REQUEST['wcam_deleted'] ) );
		   echo '<div class="updated"><p>'.$message.'</p></div>';
	     }
	}
	public function manage_attachment_counter_column( $column, $order_id ) 
	{
		global $wcam_html_model;
		
		$option = new WCAM_Option();
		$options = $option->get_option();
		
		$wcam_html_model->init_attachments_metabox_js();
		$order_id = is_object($order_id) ? $order_id->get_id() : $order_id;
		if ( $column == 'attachment-counter' ) 
		{
			global $wcam_file_model;
			//The method checks if according option the expired attachments can be deleted
			$wcam_file_model->delete_expired_attachments($order_id);
			$attachmented_files = get_post_meta($order_id, '_wcam_attachments_meta');
			
			echo '<span class="wcam_attachment_counter" id="wcam_attachment_counter_'.$order_id.'">';
			if(!$attachmented_files || empty($attachmented_files[0]))
				echo "0";
			else echo 
				count($attachmented_files[0]);
			echo '</span>';
			
			//Manage button
			?>
			<div class="wcaf-actions-container" id="wcaf-actions-container-<?php echo $order_id?>">
					<button class="button wcam-modify-order-attachments-button" id="wcam-modify-order-attachments-button-<?php echo $order_id; ?>" data-order-id="<?php echo $order_id; ?>"><?php  esc_html_e('Manage', 'woocommerce-attach-me'); ?></button>
					<img class="wcam-order-attachments-metabox-loader" id="wcam-order-attachments-metabox-loader-<?php echo $order_id; ?>" src="<?php echo wcam_PLUGIN_PATH.'/images/loading.gif'; ?>" width="24"></img>
				</div>
			<?php 	
				
		}
		if( wcam_get_value_if_set($options, array('admin_orders_list','show_approval_column'), 'false') == 'true' && $column == 'attachment-approval')
		{
			global $wcam_order_model, $wcam_time_model;
			$attachments_meta = $wcam_order_model->get_attachmets_meta($order_id);
			$show_date = false;
			foreach((array)$attachments_meta as $attachment_meta)
			{
				if(!isset($attachment_meta['id']))
						continue;
				
				echo "<h4>".(!empty($attachment_meta['title']) ? $attachment_meta['title'] : esc_html__('No title', 'woocommerce-attach-me'))."</h4>";
				echo '<p>';				
				if(!isset($attachment_meta['customer-has-approved']) || $attachment_meta['customer-has-approved'] == 'none')
				{
					echo '<h5 style="color:grey">'.esc_html__('Waiting for customer approval', 'woocommerce-attach-me').'</h5>';
				}
				else if($attachment_meta['customer-has-approved'] == 'yes')
				{
					echo '<h5 style="color:green">'.esc_html__('Customer has approved', 'woocommerce-attach-me').'</h5>';
					$show_date = true;
				}
				else
				{
					echo '<h5 style="color:red">'.esc_html__('Customer has not approved', 'woocommerce-attach-me').'</h5>';
					$show_date = true;
				}
				
				if($show_date)
				{
					$approval_date = wcam_get_value_if_set($attachment_meta, 'approval-date', "");
					$approval_date = $approval_date != "" ?  $wcam_time_model->format_date_according_wp_settings($approval_date) : esc_html__(' - ', 'woocommerce-attach-me');
					echo "<i><strong>".esc_html__('On', 'woocommerce-attach-me').":</strong> ".$approval_date."</i>";
				}
				echo '</p>';
								
			}
		}
		
	}
	
	function sort_columns( $columns)
	{
		 $columns['attachment-counter'] = 'attachment-counter';
		return $columns;
	}
	public function add_attachment_counter_column($columns)
	 {
		
	   $option = new WCAM_Option();
	   $options = $option->get_option();
	   
		wp_enqueue_style('wcam-featherlight', wcam_PLUGIN_PATH.'/css/vendor/featherlight/featherlight.min.css');
		wp_enqueue_style('wcam-info-tracking-box', wcam_PLUGIN_PATH.'/css/wcam-backend-orders-list-page.css');
		
		wp_enqueue_script('wcam-featherlight', wcam_PLUGIN_PATH.'/js/vendor/featherlight/featherlight.min.js', array('jquery'));
		
	   $columns['attachment-counter'] =__('Attachments', 'woocommerce-attach-me'); 
	   if(wcam_get_value_if_set($options, array('admin_orders_list','show_approval_column'), 'false') == 'true')
		$columns['attachment-approval'] =__('Approval status', 'woocommerce-attach-me'); 

	 
	   
	   return $columns;
	}
	public function add_attachments_select_box_filter($order_type = "shop_order", $which = "top")
	{
		global $typenow, $wp_query;
		$current_page = $typenow ? $typenow : $order_type;
		if ($current_page=='shop_order') 
		{
			$selected = isset($_GET['wcam_filter_by_attachments']) && $_GET['wcam_filter_by_attachments'] ? $_GET['wcam_filter_by_attachments']:"none";
			?>
			<select name="wcam_filter_by_attachments" >
				<option value="all" <?php if($selected == "all") echo 'selected="selected"';?>><?php esc_html_e('Orders with and without attachments', 'woocommerce-attach-me') ?></option>
				<option value="attachments-only" <?php if($selected == "attachments-only") echo 'selected="selected"';?>><?php esc_html_e('Orders with attachments', 'woocommerce-attach-me') ?></option>
			</select>
			<?php
		}
	}
	//HPOS
	function filter_order_list_query($query) 
	{
		global $wcam_upload_field_model;
		if(wcam_get_value_if_set($_GET,'wcam_filter_by_attachments', false) == 'attachments-only' && wcam_get_value_if_set($query, 'type', false) == 'shop_order')
		{
			$conditions = array(
				'key' => '_wcam_attachments_meta',
				'compare' => 'NOT NULL'
			  );

			$query['meta_query'][] = $conditions;
		}
		return $query;
	}
	function filter_query_by_attachments($query) 
	{
		global $pagenow;
		$qv = &$query->query_vars;
		if ($pagenow=='edit.php' && 
		    isset($qv['post_type']) && $qv['post_type']=='shop_order' && isset($_GET['wcam_filter_by_attachments']) && $_GET['wcam_filter_by_attachments'] == 'attachments-only') 
		{
			 $qv['meta_query'][] = 
				array(
				'key' => '_wcam_attachments_meta',
				'compare' => 'NOT NULL'
			  );
		}
		
	}
}
?>