<?php 
class WCAM_Order
{
	public function __construct()
	{
		add_action('wp_ajax_wcam_set_disclaimer_accepted_flag', array(&$this, 'ajax_set_disclaimer_flag_to_attachment'));
		add_action('wp_ajax_wcam_load_attachments_next_id', array(&$this, 'ajax_load_attachments_next_id'));
		add_action('wp_ajax_wcam_load_number_or_attachments', array(&$this, 'ajax_load_number_or_attachments'));
	}
	
	static function get_billing_email($order)
	{
		if(version_compare( WC_VERSION, '2.7', '<' ))
			return $order->billing_email;
		
		return $order->get_billing_email();
	}
	static function get_customer_id($order)
	{
		if(version_compare( WC_VERSION, '2.7', '<' ))
			return $order->customer_user;
		
		return $order->get_customer_id();
	}
	public static function get_id($order)
	{
		if(version_compare( WC_VERSION, '2.7', '<' ))
			return $order->id;
		
		return $order->get_id();
	}
	public function ajax_load_number_or_attachments()
	{
		$order_id = isset($_POST['order_id']) ? $_POST['order_id'] : false;
		if(!$order_id)
		{
			echo 0;
			wp_die();
		}
		
		$attachments_meta = $order_id != "none" ? $this->get_attachmets_meta($order_id) : array();
		echo is_array($attachments_meta) ? count($attachments_meta) : 0;
		
		wp_die();
	}
	public function ajax_load_attachments_next_id()
	{
		$order_id = isset($_POST['order_id']) ? $_POST['order_id'] : false;
		if(!$order_id)
		{
			echo 0;
			wp_die();
		}
		
		echo $this->get_next_attachment_id($order_id);
		wp_die();
	}
	public function get_next_attachment_id($order_id)
	{
		$attachments_meta = $order_id != "none" ? $this->get_attachmets_meta($order_id) : array();
		
		$counter = $max_id = 0;
		if(isset($attachments_meta) && !empty($attachments_meta))
			foreach((array)$attachments_meta as $attachment_meta)
			{
					if(!isset($attachment_meta['id']))
							continue;
			 $counter = $attachment_meta['id']; 
			 $max_id = $max_id < $counter ? $counter : $max_id;
			}
		return $max_id + 1;
	}
	
	public static function get_date_created($order)
	{
		if(version_compare( WC_VERSION, '2.7', '<' ))
			return $order->order_date;
		
		$object = $order->get_date_created();
		if(!$object)
			return date('Y-m-d H:i:s');
		return $object->date('Y-m-d H:i');
	}
	public function get_lang($order)
	{
		$wpml = new WCAM_Wpml();
		$wc_order = is_object($order) ? $order : wc_get_order($order);
		$default = $wpml->get_current_language(); //exameple en;

		if(!isset($order) || $order == false)
			return $default;
		
		$result = $wc_order->get_meta('wpml_language');
		$result = !$result || !is_string($result) || $result == "" ? $default : $result;
		
		return strtolower($result);
	}
	function get_order_details_page_url($order)
	{
		
		$order = is_object($order) ? $order : wc_get_order($order);
		if(!isset($order) || $order === false)
			return "";
		
		$order_url = $order->get_customer_id() ? $order->get_view_order_url(): 
												 $order->get_checkout_order_received_url( ); 
												 
		return $order_url;
	}
	public function ajax_set_disclaimer_flag_to_attachment()
	{
		$order_id = isset($_POST['order_id']) ? $_POST['order_id'] : null;
		$file_id = isset($_POST['file_id']) ? $_POST['file_id'] : null;
		$order = $order_id != null ? wc_get_order($order_id) : false;
		if($order_id != null && $file_id != null && $order)
		{
			$this->set_attachment_attribute($order_id, $file_id, 'disclaimer-has-been-accepted-by-user', 'yes');
		}
		wp_die();
	}
	public function set_attachment_attribute($order_id, $file_id, $attribute_name, $attribute_value)
	{
		$file_order_metadata = $this->get_attachments_metadata($order_id, array());
		$file_order_metadata[$file_id][$attribute_name] = $attribute_value;
		$this->update_meta( $order_id, '_wcam_attachments_meta', $file_order_metadata);
	}
	public function get_user_orders($user_id)
	{
		
		$orders = wc_get_orders(array(
						'customer_id' => $user_id,
						//'return' => 'ids'
				));
		
		return $orders;
		
		//Old method 
		$customer_orders = get_posts( array(
				'numberposts' => -1,
				'meta_key'    => '_customer_user',
				'meta_value'  => $user_id,
				'post_type'   => wc_get_order_types(),
				'post_status' => array_keys( wc_get_order_statuses() ),
			) );
			
		return $customer_orders;
	}
	public function get_attachments_metadata($order_id, $default_value = null)
	{
		if(version_compare( WC_VERSION, '2.7', '<' ))
		{
			$wcam_meta_data = get_post_meta($order_id, '_wcam_attachments_meta');
			$wcam_meta_data = isset($wcam_meta_data) && isset($wcam_meta_data[0]) ? $wcam_meta_data[0]:$default_value;
		}
		else 
		{
			$order = wc_get_order($order_id);
			$wcam_meta_data = $order ? $order->get_meta('_wcam_attachments_meta') : array();
			
		}
		return is_array($wcam_meta_data) ? $wcam_meta_data : array();
	}
	public function number_of_visible_attachments($order)
	{
		global $wcam_file_model;
		$exists_at_least_one_attachment_to_show = 0;
		
		//The method checks if according option the expired attachments can be deleted
		$wcam_file_model->delete_expired_attachments(WCAM_Order::get_id($order));
		$file_order_metadata = $this->get_attachments_metadata(WCAM_Order::get_id($order), array());
		
		foreach($file_order_metadata as $file_fields)
		{
			$current_status = "wc-".$order->get_status( );
			
			if( !$this->is_attachment_expired($file_fields, WCAM_Order::get_date_created($order)) && !isset($file_fields['order-attachment-hide-by-status']) || !in_array($current_status, $file_fields['order-attachment-hide-by-status']))
			{
				$exists_at_least_one_attachment_to_show++;
			}
		}
		
		return $exists_at_least_one_attachment_to_show;
	}
	public function get_attachmets_meta($order_id)
	{
		$order = wc_get_order($order_id);
		$file_order_metadata = version_compare( WC_VERSION, '2.7', '<' ) ? get_post_meta($order_id, '_wcam_attachments_meta', true) : $order->get_meta('_wcam_attachments_meta',  true);
		return isset($file_order_metadata) ? $file_order_metadata:array();
	}
	public function get_post_options($order_id)
	{
		$order = wc_get_order($order_id);
		$wcam_options = version_compare( WC_VERSION, '2.7', '<' ) ? get_post_meta( $order_id, '_wcam_options', true) :$order->get_meta('_wcam_options',  true) ;
		return isset($wcam_options) && isset($wcam_options) && is_array($wcam_options) ? $wcam_options:array();
	}
	public function update_meta($order_id, $key, $value)
	{
		if(version_compare( WC_VERSION, '2.7', '<' ))
			update_post_meta( $order_id, $key, $value);
		else 
		{
			$order = wc_get_order($order_id);
			$order->update_meta_data( $key, $value);
			$order->save( );
		}
	}
	public function process_upload_csv_chunk($csv_array)
	{
		$attachmets_added = 0;
		$errors = array();
		$messages = array();
		$columns_names = array("order_id",
								"title",
								"url",
								"customer-has-to-be-approved",
								"customer-can-reapprove",
								"customer-feedback-enabled",
								"customer-admin-notification");
		$colum_index_to_name = array();
		$row = 1;
		$real_row = 1;
		if($csv_array != null)
		{
			foreach($csv_array as $csv_row)
			{
				$data = str_getcsv($csv_row);
				$num = count($data);
				$attachment = array();
				
				for ($c=0; $c < $num; $c++) 
				{						
					if($row == 1)
					{
						foreach( $columns_names as $title)
							if($title == $data[$c])
									$colum_index_to_name[$c] = $title;
					}
					else
					{
						if(isset($colum_index_to_name[$c]))
						{
							$attachment[$colum_index_to_name[$c]] = $data[$c];
						}
					}
					
				}
				if($attachment != null && !empty($attachment) && isset($attachment['order_id']))
				{
					if ( isset($attachment['order_id']) && isset($attachment['title']) && isset($attachment['url']))
					{
						$attachments_meta = get_post_meta($attachment['order_id'], '_wcam_attachments_meta');
						$id = 0;
						$file_order_metadata = array();
						$file_order_metadata[$id] = array();
						if(isset($attachments_meta[0]))
						{
							foreach($attachments_meta[0] as $attachment_meta)		
								$id = $attachment_meta['id'] > $id ? $attachment_meta['id'] : $id; 
							$id++;
							
							$file_order_metadata = $attachments_meta[0];
						}
						
						$this->save_single_attachment_meta_data($id, $attachment, $file_order_metadata, array($id => $attachment['title']), $attachment['order_id'], true, $attachment['url']);
						$this->update_meta( $attachment['order_id'], '_wcam_attachments_meta', $file_order_metadata);
						$attachmets_added++;
					}
					else
					{
						if(!isset($attachment['title']))
							array_push( $errors, new WP_Error('order', sprintf(esc_html__("Order attachment title is not valid for %d.", 'woocommerce-attach-me'), $real_row)));
						else 
							array_push( $errors, new WP_Error('order', sprintf(esc_html__("Order attachment url is not valid for %d.", 'woocommerce-attach-me'), $real_row)));
						
					}
						
						$real_row++;
				}
				$row++;
			}
			array_push( $messages, sprintf(esc_html__('Added %d attachments!', 'woocommerce-attach-me'),  $attachmets_added ));
			
		}
		return array('messages' => $messages, 'errors' => $errors);
	}
	public function save_attachments($meta_info, $files)
	{
		$results = $errors = "";
		global $wcam_file_model;
		$order_id = $meta_info["wcam-orderid"];
		$file_order_metadata = $this->get_attachmets_meta($order_id );
		
		
		//Delete
		if(isset($meta_info['wcam_attachments_to_delete']))
		{
			foreach($meta_info['wcam_attachments_to_delete'] as $value)
			{
				$file_order_metadata = $wcam_file_model->delete_file(intval($value), $file_order_metadata, $order_id);
			}
		} 
		
		$titles = isset($meta_info['wcam_attachment_title']) ? $meta_info['wcam_attachment_title'] : array();
		//wcam_var_dump($meta_info);
		
		//Upload
		if(isset($files))
		{
			$wcam_file_model->upload_files($order_id, $file_order_metadata, $files, $titles, $meta_info);
		}
		if(isset($meta_info['wcam_attachment_external_url']))
		{	
			$this->bulk_save_meta_data($titles, $meta_info, $file_order_metadata, 'wcam_attachment_external_url', $order_id);	
		}
		if(isset($meta_info['wcam_attachment_gallery_url']))
		{	
			$this->bulk_save_meta_data($titles, $meta_info, $file_order_metadata, 'wcam_attachment_gallery_url', $order_id);
		}
		
		
		$this->update_meta( $order_id, '_wcam_attachments_meta', $file_order_metadata);
		
		//general options
		$wcam_options = array();
		$wcam_options['embed-links-preset-email-text-id'] = isset($meta_info['wcam-embed-links-preset-email-text-id']) ? $meta_info['wcam-embed-links-preset-email-text-id'] : "no";
		$wcam_options['notification-preset-email-text-id'] = isset($meta_info['wcam-notification-preset-email-text-id']) ? $meta_info['wcam-notification-preset-email-text-id'] : "no";
		$wcam_options['embed-links-to-complete-mail'] = isset($meta_info['wcam-embed-links-to-complete-mail']) ? $meta_info['wcam-embed-links-to-complete-mail'] : "no";
		$wcam_options['embed-links-hide-by-status'] = isset($meta_info['wcam-embed-links-hide-by-status']) ? $meta_info['wcam-embed-links-hide-by-status'] : array();
		$wcam_options['embed-links-to-complete-mail-text'] = isset($meta_info['wcam-embed-links-to-complete-mail-text']) ? $meta_info['wcam-embed-links-to-complete-mail-text'] : ""; 
		$this->update_meta( $order_id, '_wcam_options', $wcam_options);
		
		//Email notification
		if(isset($meta_info['wcam-notify-via-mail']) && $meta_info['wcam-notify-via-mail'] == 'yes')
		{
			$results = WCAM_Notifier::send_user_email($meta_info, $file_order_metadata,$order_id);
		}	
		return array('results' => $results, 'errors'=> $errors);		
	}
	public function bulk_save_meta_data($titles, $meta_info, &$file_order_metadata, $type, $order_id)
	{
		foreach($meta_info[$type] as $index => $url)
		{
			if($url == "")
				continue;
			
			$id = $meta_info['wcam_id'][$index];
			$this->save_single_attachment_meta_data($id, $meta_info, $file_order_metadata, $titles, $order_id);
		
			if($type == 'wcam_attachment_external_url')
			{
				$file_order_metadata[$id]['absolute_path'] = "";
				$file_order_metadata[$id]['media_from_gallery'] = "no";
				$file_order_metadata[$id]['url'] = $file_order_metadata[$id]['secure-download'] == "no" ? $url :  get_site_url()."?wcam_id=".$order_id."-".$id;
				$file_order_metadata[$id]['original_url'] = $url;
			}
			
			if($type == 'wcam_attachment_gallery_url')
			{
				$file_order_metadata[$id]['url'] = $file_order_metadata[$id]['secure-download'] == "no" ? $url :  get_site_url()."?wcam_id=".$order_id."-".$id;
				$file_order_metadata[$id]['media_from_gallery'] = "yes";
				$file_order_metadata[$id]['media_id'] = isset($meta_info['wcam_attachment_gallery_media_id']) && isset($meta_info['wcam_attachment_gallery_media_id'][$id]) ? $meta_info['wcam_attachment_gallery_media_id'][$id] : -1;
				$file_order_metadata[$id]['absolute_path'] = $file_order_metadata[$id]['media_id'] !=0 ? get_attached_file( $file_order_metadata[$id]['media_id'] ) : "";
				$file_order_metadata[$id]['original_url'] = $url;
			}
		}
	}
	public function save_single_attachment_meta_data($id, $meta_info, &$file_order_metadata, $titles, $order_id, $absolute_path = null, $url = null)
	{
		//Common metadata
		$file_order_metadata = !is_array($file_order_metadata) ? array() : $file_order_metadata;
		
		$file_order_metadata[$id]['title'] = !empty($titles) && isset($titles[$id]) ? $titles[$id] : "";
		$file_order_metadata[$id]['id'] = $id;
		$file_order_metadata[$id]['description'] =  isset($meta_info['wcam-attachment-description'][$id]) && $meta_info['wcam-attachment-description'][$id] != "" ? $meta_info['wcam-attachment-description'][$id] : null ;
		$file_order_metadata[$id]['secure-download'] = isset($meta_info['wcam-secure-download'][$id]) ? $meta_info['wcam-secure-download'][$id] : "no" ;
		$file_order_metadata[$id]['customer-has-to-be-approved'] = isset($meta_info['wcam-customer-approve-checkbox'][$id]) ? $meta_info['wcam-customer-approve-checkbox'][$id] : "no";
		$file_order_metadata[$id]['customer-can-reapprove'] = isset($meta_info['wcam-customer-reapprove-checkbox'][$id]) ? $meta_info['wcam-customer-reapprove-checkbox'][$id]: "no";
		$file_order_metadata[$id]['customer-feedback-enabled'] = isset($meta_info['wcam-customer-feedback-checkbox'][$id]) ? $meta_info['wcam-customer-feedback-checkbox'][$id] : "no";
		$file_order_metadata[$id]['customer-feedback-cannot-be-modified-after-submit'] = isset($meta_info['wcam-customer-cannot-modify-feedback-after-sumbit'][$id]) ? $meta_info['wcam-customer-cannot-modify-feedback-after-sumbit'][$id] : "no";
		$file_order_metadata[$id]['customer-feedback-strategy'] = isset($meta_info['wcam-customer-feedback-strategy'][$id]) ? $meta_info['wcam-customer-feedback-strategy'][$id] : "never";
		$file_order_metadata[$id]['customer-admin-notification'] = isset($meta_info['wcam-customer-admin-notification-checkbox'][$id]) ? $meta_info['wcam-customer-admin-notification-checkbox'][$id] : "no";
		$file_order_metadata[$id]['attach-file-to-processing-order-email'] = isset($meta_info['wcam-attach-file-to-processing-order-email'][$id]) ? $meta_info['wcam-attach-file-to-processing-order-email'][$id] : "no";
		$file_order_metadata[$id]['attach-file-to-complete-order-email'] = isset($meta_info['wcam-attach-file-to-complete-order-email'][$id]) ? $meta_info['wcam-attach-file-to-complete-order-email'][$id] : "no";
		$file_order_metadata[$id]['attach-file-to-customer-invoice-email'] = isset($meta_info['wcam-attach-file-to-customer-invoice-email'][$id]) ? $meta_info['wcam-attach-file-to-customer-invoice-email'][$id] : "no";
		$file_order_metadata[$id]['attach-file-to-order-refunded-email'] = isset($meta_info['wcam-attach-file-to-order-refunded-email'][$id]) ? $meta_info['wcam-attach-file-to-order-refunded-email'][$id] : "no";
		$file_order_metadata[$id]['order-attachment-hide-by-status'] = isset($meta_info['wcam-order-attachment-hide-by-status'][$id]) ? $meta_info['wcam-order-attachment-hide-by-status'][$id] : array();
		$file_order_metadata[$id]['display-copy-to-clipboard-button'] = isset($meta_info['wcam-display-copy-to-clipboard-button'][$id]) ? $meta_info['wcam-display-copy-to-clipboard-button'][$id] : "no";
		$file_order_metadata[$id]['download-only-if-disclaimer-has-been-accepted'] = isset($meta_info['wcam-download-only-if-disclaimer-has-been-accepted'][$id]) ? $meta_info['wcam-download-only-if-disclaimer-has-been-accepted'][$id] : "no";
		//expiration
		$file_order_metadata[$id]['expiration-strategy'] = isset($meta_info['wcam_expiration_strategy'][$id]) ? $meta_info['wcam_expiration_strategy'][$id] : "never";
		$file_order_metadata[$id]['expiration-relative-time-amount'] = isset($meta_info['wcam_expiration_relative_time_amount'][$id]) ? $meta_info['wcam_expiration_relative_time_amount'][$id] : "";
		$file_order_metadata[$id]['expiration-relative-time-type'] = isset($meta_info['wcam_expiration_relative_time_type'][$id]) ? $meta_info['wcam_expiration_relative_time_type'][$id] : "";
		$file_order_metadata[$id]['expiration-specific-date'] = isset($meta_info['wcam_expiration_specific_date'][$id]) ? $meta_info['wcam_expiration_specific_date'][$id] : "";
		
		$file_order_metadata[$id]['wc_custom_order_emails_attachment'] = isset($meta_info['wcam_wc_custom_order_emails_attachment'][$id]) ? $meta_info['wcam_wc_custom_order_emails_attachment'][$id] : array();
		
		//downloads
		$file_order_metadata[$id]['downloads-table-custom-title-column'] = isset($meta_info['wcam-downloads-table-custom-title-column'][$id]) ? $meta_info['wcam-downloads-table-custom-title-column'][$id] : "";
		$file_order_metadata[$id]['downloads-table-hide'] = isset($meta_info['wcam-downloads-table-hide'][$id]) ? $meta_info['wcam-downloads-table-hide'][$id] : "no";
		
		if(isset($absolute_path))
		{
			$file_order_metadata[$id]['absolute_path'] = $absolute_path;
			$file_order_metadata[$id]['url'] = $file_order_metadata[$id]['secure-download'] == "no" ? $url :  get_site_url()."?wcam_id=".$order_id."-".$id;
		}
		
	}
	public function is_attachment_expired($attachment_data, $order_date)
	{
		
		if(!isset($attachment_data['expiration-strategy']))
			return false;
		
		$format = $attachment_data['expiration-strategy'] == 'specific_date' ? 'Y/m/d H:i:s' : "d/m/Y H:i:s";
		
		$result = wcam_is_expiring_date_valid($attachment_data['expiration-strategy'], $order_date, $format, $attachment_data['expiration-specific-date'], $attachment_data['expiration-relative-time-amount'] ,$attachment_data['expiration-relative-time-type']);	
		$has_expired = $result['has_expired'];
		$expiring_date = $result['expiring_date'];
						
		return $has_expired;
	}
	public function get_attachment_expiration_date($order_id, $attachment_meta)
	{
		
		$order = wc_get_order($order_id);
		$date = "";
		if(isset($attachment_meta['expiration-strategy']))
			switch($attachment_meta['expiration-strategy'])
			{
				case 'specific_date': $date = wcam_format_datetime_according_wordpress_settings($attachment_meta['expiration-specific-date']); 
				break;
				case 'relative_date': $date = wcam_get_absolute_date_from_time_amout_plus_date(WCAM_Order::get_date_created($order), $attachment_meta['expiration-relative-time-amount'], $attachment_meta['expiration-relative-time-type']); 
				break;
			} 
		return $date;
	}
	public function replace_shortcodes_with_order_data($message, $order)
	{
		$order = is_numeric($order) ? wc_get_order($order) : $order;
		if(!is_object($order))
			return $message;
		
		$billing_fields = array('order_id', 'order_date_created', 'billing_first_name', 'billing_last_name', 'billing_company', 'billing_address_1', 'billing_address_2', 'billing_city', 'billing_state', 'billing_postcode', 'billing_country', 'billing_email', 'billing_phone');
		$shipping_fields = array('shipping_first_name', 'shipping_last_name', 'shipping_company', 'shipping_address_1', 'shipping_address_2', 'shipping_city', 'shipping_state', 'shipping_postcode', 'shipping_country');
		
		
		foreach ( $billing_fields as $key) 
		{
			$key_method = str_replace("order_", "", $key);
			if ( is_callable( array( $order, "get_{$key_method}" ) )  ) 
			{
				$method_name = "get_".$key_method;
				$key_value = $key == 'order_id' ? apply_filters('wcam_get_visual_order_id', $order->$method_name()) : $order->$method_name();
				$message = str_replace("[{$key}]", $key_value, $message );

			
			} 
		}
	
		foreach ( $shipping_fields as $key ) 
		{
			if ( is_callable( array( $order, "set_{$key}" ) ) && is_callable( array( $order, "get_{$key}" ) ) ) 
			{
				$method_name = "get_".$key;
				$message = str_replace("[{$key}]", $order->$method_name(), $message );
			}
		}
				
		return $message;
	}
}
?>