<?php 
class WCAM_DownloadsPage
{
	var $options;
	public function __construct()
	{
		//Add attachments to order downloads 
		add_filter('woocommerce_customer_get_downloadable_products', array(&$this, 'add_attachments_to_downloadable_products'));
		
		//Additional columns managment
		add_filter('woocommerce_account_downloads_columns', array(&$this, 'add_extra_colum'));
		add_action('woocommerce_account_downloads_column_download-product', array(&$this, 'add_order_id_column_content'));
		add_action('woocommerce_account_downloads_column_download-has-to-be-approved', array(&$this, 'add_approval_column_content'));
		add_filter('woocommerce_account_downloads_column_download-file', array(&$this, 'remove_download_button_for_expired'), 99);
	}
	public function add_extra_colum($columns)
	{
		$options = new WCAM_Option();
		$this->options = $options->get_option();
		if(!isset($this->options['show_attachments_in_downloads_page']))
			return $columns;
		
		$new_columns = array();
		foreach($columns as $key => $content)
		{
			$new_columns[$key] = $content;
			if($key == 'download-expires' && !isset($this->options['hide_approval_required_column']))
			{
				$new_columns['download-has-to-be-approved'] = esc_html__( 'Approval required', 'woocommerce-attach-me' );
			}
		}
		return $new_columns;
	}
	public function add_order_id_column_content($download)
	{
		if(isset($download['is_managed_by_wcam']))
		{
			if($download['is_order_attachment'])
				$order_page_url = '<a href="'.add_query_arg('view-order', $download['order_id'], get_permalink( get_option( 'woocommerce_myaccount_page_id' ) )  ).'" target="_blank" >'.$download['product_name'].'</a>';
			else	
				$order_page_url = '<a href="'.get_permalink( $download['product_id'] ).'" target="_blank" >'.$download['custom_product_name'].'</a>'; //It is not clear why if using 'product_name' index, the name cannot be customized
			
			echo $order_page_url;
		}
		else
		{
			?>
			<a href="<?php echo esc_url( get_permalink( $download['product_id'] ) ); ?>" target="_blank">
				<?php echo esc_html( $download['product_name'] ); ?>
			</a>
			<?php 
		}
	}
	public function add_approval_column_content($download)
	{
		$order_page_url = '<a href="'.add_query_arg('view-order', $download['order_id'], get_permalink( get_option( 'woocommerce_myaccount_page_id' ) )  ).'" target="_blank">'.esc_html__('Yes', 'woocommerce-attach-me').'</a>';
		
		if(isset($download["customer-has-to-be-approved"]) && $download["customer-has-to-be-approved"])
			echo $order_page_url;
		else
			_e( 'No', 'woocommerce-attach-me' );
		
	}
	public function remove_download_button_for_expired($actions)
	{
		foreach ( $actions as $key => $action ) 
			if($key == 'download_url')
			{
				if($action != "#wcam_expired")
				{
					echo '<a href="' . esc_url( $action ) . '" class="button woocommerce-Button ' . sanitize_html_class( $key ) . '" download="">' . esc_html__('Download', 'woocommerce') . '</a>';
				}
				else
					_e('Expired','woocommerce-attach-me'); 				
			}
	}
	public function add_attachments_to_downloadable_products($downloads)
	{
		if(!isset($this->options))
		{	
			$options = new WCAM_Option();
			$this->options = $options->get_option();
		}
		if(!isset($this->options['show_attachments_in_downloads_page']))
			return $downloads;
		
		global $wcam_order_model, $wcam_product_model ;
		$user_id = get_current_user_id();
		$user_orders = $wcam_order_model->get_user_orders($user_id);
		
		if($user_orders)
			foreach((array)$user_orders as $order)
			{
				$order_date = $order->get_date_created();
				$order_date = $order_date->date('Y/m/d H:i:s');
				$current_status = "wc-".$order->get_status( );
				$product_attachments = $wcam_product_model->get_attachments_downloadable_in_order_details_page($order);
				$order_attachments = $wcam_order_model->get_attachments_metadata($order->get_id() , array());
				
				if($product_attachments && is_array($product_attachments) && !empty($product_attachments))
				{
					$product_attachments = array_reverse($product_attachments);
					foreach($product_attachments as $product_name => $attached_files)
					{
						foreach($attached_files as $product_attachment)
						{
							$order_status_visibility = wcam_get_value_if_set($product_attachment, 'order_status_visibility', array());
							
							if(!in_array($current_status, $order_status_visibility) && !empty($order_status_visibility))
								continue;
							
							if(isset($downloads[$product_attachment["id"]]))
								continue;
							
							
							if($product_attachment["downloads_table_hide"])
								continue;
							
							$custom_product_name = wcam_get_value_if_set($product_attachment, 'downloads_table_custom_title_column', "") != "" ? $product_attachment["downloads_table_custom_title_column"] : $product_name;
							
							$attachment = array();
							$attachment['is_managed_by_wcam'] = true;
							$attachment['is_order_attachment'] = false;
							$attachment['download_url'] = $product_attachment['has_expired'] ? "#wcam_expired" : $product_attachment["file_url"];
							$attachment['download_id'] = $product_attachment["id"];
							$attachment['download_name'] = $product_attachment["file_name"];
							$attachment['name'] = $product_attachment["file_name"];
							$attachment['custom_product_name'] = $custom_product_name;  //It is not clear why if using 'product_name' index, the name cannot be customized
							$attachment['order_id'] = $order->get_id();							
							$attachment['product_id'] =$product_attachment["product_id"];
							$attachment['downloads_remaining'] = "";
							$attachment['order_key'] = "";
							$attachment['file'] = array();
							$attachment['file']['name'] = $product_attachment["file_name"];
							$attachment['access_expires'] = wcam_format_dateime_obj_according_wordpress($product_attachment['expiring_date']);
							$downloads[$product_attachment["id"]] = $attachment; //id to avoid to attach same file associated to different products
							
							
						}
					}
				}				
				if($order_attachments && is_array($order_attachments) && !empty($order_attachments))
				{
					$order_attachments = array_reverse($order_attachments);
					foreach($order_attachments as $order_attachment)
					{
						if(count($order_attachment) < 2)
							continue;
						if(in_array($current_status, wcam_get_value_if_set($order_attachment, 'order-attachment-hide-by-status', array())))
							continue;
							
						if($wcam_order_model->is_attachment_expired($order_attachment, $order_date))
							continue;
						if(wcam_get_value_if_set($order_attachment, "disclaimer-has-been-accepted-by-user", "") != 'yes' && wcam_get_value_if_set($order_attachment,"download-only-if-disclaimer-has-been-accepted","") == 'yes')
							continue;
						
						if(wcam_get_value_if_set($order_attachment, 'downloads-table-hide', "no") == 'yes')
							continue;
						
						
						$is_expired = $wcam_order_model->is_attachment_expired($order_attachment, $order_date);
						$attachment = array();
						
						$title = isset($order_attachment["downloads-table-custom-title-column"]) && $order_attachment["downloads-table-custom-title-column"] != "" ?  $order_attachment["downloads-table-custom-title-column"] : sprintf(esc_html__( 'Order #%s', 'woocommerce-attach-me' ), apply_filters('wcam_get_visual_order_id', $order->get_id()));
						
						$attachment['is_managed_by_wcam'] = true;
						$attachment['is_order_attachment'] = true;
						$attachment['download_url'] =  $is_expired ? "#wcam_expired" : $order_attachment["url"];
						$attachment['customer-has-to-be-approved'] = $order_attachment["customer-has-to-be-approved"] == 'yes' ? true : false;
						$attachment['download_id'] = $order->get_id()."-".$order_attachment["id"];
						$attachment['download_name'] = $order_attachment["title"];
						$attachment['name'] = $order_attachment["title"];
						$attachment['product_name'] = $title;
						$attachment['order_id'] = $order->get_id();
						$attachment['product_id'] = "";
						$attachment['downloads_remaining'] = "";
						$attachment['order_key'] = "";
						$attachment['file'] = array();
						$attachment['file']['name'] = $order_attachment["title"];
						$attachment['access_expires'] = $wcam_order_model->get_attachment_expiration_date($order->get_id(), $order_attachment);
						$downloads[] = $attachment; //id to avoid to attach same file associated to different products
					}
				}
				
			}
		return $downloads;
	}
}
?>